pub struct CameraBundle { /* private fields */ }Implementations
Sourceimpl CameraBundle
impl CameraBundle
Sourcepub fn new(camera: Cameraman, bundle: Camera2dBundle) -> Self
pub fn new(camera: Cameraman, bundle: Camera2dBundle) -> Self
Examples found in repository?
examples/full.rs (lines 45-48)
23fn setup_example(
24 mut commands: Commands,
25 mut meshes: ResMut<Assets<Mesh>>,
26 mut materials: ResMut<Assets<ColorMaterial>>,
27) {
28 // 1. spawn your entity to follow
29 let entity = commands
30 .spawn((
31 MaterialMesh2dBundle {
32 mesh: meshes.add(shape::Circle::new(30.).into()).into(),
33 material: materials.add(ColorMaterial::from(Color::rgb(0.8, 0.3, 0.3))),
34 transform: Transform::from_translation(Vec3::new(-150., 0., 0.)),
35 ..default()
36 },
37 LocalPlayer {},
38 // you need this to tell the camera to focus this entity
39 Target,
40 ))
41 .id();
42
43 // 2. spawn your cameraman and make it follow previou entity
44 // you should play with the cameraman values!
45 commands.spawn(CameraBundle::new(
46 Cameraman::new(entity, Vec2::new(50.0, 20.0), Vec3::ONE * 0.8),
47 Camera2dBundle::default(),
48 ));
49}pub fn new_with_default_bundle(target: Entity) -> Self